@@ -29,7 +29,7 @@ def zipapp_build_env(tmp_path_factory):
                 try:
                     # create a virtual environment which is also guaranteed to contain a recent enough pip (bundled)
                     session = run_via_cli(
-                        ["-v", "-p", "{}3.{}".format(impl, version), "--activators", "", str(create_env_path)]
+                        ["-vvv", "-p", "{}3.{}".format(impl, version), "--activators", "", str(create_env_path)]
                     )
                     exe = str(session.creator.exe)
                     found = True
@@ -69,7 +69,7 @@ def zipapp_test_env(tmp_path_factory):
 @pytest.fixture()
 def call_zipapp(zipapp, monkeypatch, tmp_path, zipapp_test_env):
     def _run(*args):
-        monkeypatch.setenv(str("_VIRTUALENV_OVERRIDE_APP_DATA"), str(tmp_path / "app_data"))
+        monkeypatch.setenv(str("VIRTUALENV_OVERRIDE_APP_DATA"), str(tmp_path / "app_data"))
         cmd = [str(zipapp_test_env), str(zipapp), "-vv", six.ensure_text(str(tmp_path / "env"))] + list(args)
         subprocess.check_call(cmd)
 
