@@ -174,8 +174,8 @@ def test_create_no_seed(python, creator, isolated, system, coverage_env, special
 
 @pytest.mark.skipif(not CURRENT.has_venv, reason="requires interpreter with venv")
 def test_venv_fails_not_inline(tmp_path, capsys, mocker):
-    def _session_via_cli(args):
-        session = session_via_cli(args)
+    def _session_via_cli(args, options=None):
+        session = session_via_cli(args, options)
         assert session.creator.can_be_inline is False
         return session
 
@@ -281,7 +281,7 @@ def test_cross_major(cross_python, coverage_env, tmp_path, current_fastest):
 
 
 def test_create_parallel(tmp_path, monkeypatch):
-    monkeypatch.setenv(str("_VIRTUALENV_OVERRIDE_APP_DATA"), str(tmp_path))
+    monkeypatch.setenv(str("VIRTUALENV_OVERRIDE_APP_DATA"), str(tmp_path))
 
     def create(count):
         subprocess.check_call([sys.executable, "-m", "virtualenv", str(tmp_path / "venv{}".format(count))])
@@ -297,3 +297,18 @@ def test_creator_input_passed_is_abs(tmp_path, monkeypatch):
     monkeypatch.chdir(tmp_path)
     result = Creator.validate_dest("venv")
     assert str(result) == str(tmp_path / "venv")
+
+
+def test_create_long_path(current_fastest, tmp_path):
+    if sys.platform == "darwin":
+        max_shebang_length = 512
+    else:
+        max_shebang_length = 127
+    # filenames can be at most 255 long on macOS, so split to to levels
+    count = max_shebang_length - len(str(tmp_path))
+    folder = tmp_path / ("a" * (count // 2)) / ("b" * (count // 2)) / "c"
+    folder.mkdir(parents=True)
+
+    cmd = [str(folder)]
+    result = run_via_cli(cmd)
+    subprocess.check_call([str(result.creator.script("pip")), "--version"])
